@@ -1,4 +1,4 @@
-package Pcore::API::Moz v0.1.0;
+package Pcore::API::Moz v0.2.0;
 
 use Pcore -dist, -class;
 use Pcore::API::Response;
@@ -14,7 +14,7 @@ has _pool => ( is => 'ro', isa => ArrayRef, default => sub { [] }, init_arg => u
 sub check ( $self, $cb = undef ) {
     my $blocking_cv = defined wantarray ? AE::cv : undef;
 
-    $self->search(
+    $self->url_metrics(
         ['google.com'],
         103079215104,
         sub ($res) {
@@ -37,7 +37,7 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
     die q[Max. 10 domains are allowed per search] if $domains->@* > 10;
 
     if ( $self->{_threads} > 0 ) {
-        push $self->{_pool}->@*, [ $domains, $cb ];
+        push $self->{_pool}->@*, [ $domains, $metric, $cb ];
 
         return;
     }
@@ -82,7 +82,7 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
             $self->{_threads}--;
 
             if ( my $next_call = shift $self->{_pool}->@* ) {
-                $self->search( $next_call->@* );
+                $self->url_metrics( $next_call->@* );
             }
 
             $cb->($api_res);
@@ -98,11 +98,11 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
 ## PerlCritic profile "pcore-script" policy violations:
-## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
-## │ Sev. │ Lines                │ Policy                                                                                                         │
-## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    2 │ 19                   │ ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     │
-## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    2 | 19                   | ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
 __END__
